@@ -13,8 +13,9 @@ void Remailer::mail()
            d_mailType == CLEAR ? d_contentsName : d_reencryptedName, 
                 not envelopeOK()            // specify 'dontSend'
                 ||
-                d_arg.option(0, "no-mail") || configField("noMail") == "true"
-                
+                d_preamble.arg.option(0, "no-mail") 
+                || 
+                configField("noMail") == "true"
     );
 }
 
